package ch.epfl.ppo.gui;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JFrame;
import javax.swing.Timer;

import ch.epfl.ppo.Animation;
import ch.epfl.ppo.ColorRGB;
import ch.epfl.ppo.ConstantAnimation;
import ch.epfl.ppo.Image;
import ch.epfl.ppo.generators.ChessboardGenerator;

public final class AnimationViewer {
    public static void main(String[] args) {
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
                try {
                    Image<ColorRGB> chessboard = new ChessboardGenerator(ColorRGB.BLACK, ColorRGB.WHITE, 0.2);
                    // L'animation à afficher, à modifier au fur et à mesure de
                    // votre avancement.
                    final Animation<ColorRGB> animation = new ConstantAnimation<>(chessboard);

                    JFrame mainWindow = new JFrame("Animation viewer");
                    mainWindow.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

                    mainWindow.getContentPane().setLayout(new BorderLayout());
                    final ImageComponent imageComponent = new ImageComponent(animation.imageAt(0), 0, 0, 4);
                    mainWindow.getContentPane().add(imageComponent, BorderLayout.CENTER);

                    mainWindow.pack();
                    mainWindow.setVisible(true);

                    final long startingTime = System.nanoTime();
                    new Timer(1000 / 30, new ActionListener() {
                        @Override
                        public void actionPerformed(ActionEvent e) {
                            long deltaNs = System.nanoTime() - startingTime;
                            double deltaS = deltaNs / 1e9;
                            imageComponent.setImage(animation.imageAt(deltaS));
                        }
                    }).start();
                } catch (Exception e) {
                    e.printStackTrace(System.err);
                }
            }
        });
    }
}
